part of '../neon_spreed.dart';

class SpreedCallParticipantView extends StatelessWidget {
  const SpreedCallParticipantView({
    required this.participant,
    required this.localAudioEnabled,
    required this.localVideoEnabled,
    required this.localScreenEnabled,
    super.key,
  });

  final SpreedCallParticipant participant;
  final bool localAudioEnabled;
  final bool localVideoEnabled;
  final bool localScreenEnabled;

  @override
  Widget build(final BuildContext context) {
    final hasEnabledVideoTracks =
        participant.renderer?.srcObject?.getVideoTracks().where((final track) => track.enabled).isNotEmpty ?? false;
    final audioEnabled = participant is SpreedLocalCallParticipant
        ? localAudioEnabled
        : (participant as SpreedRemoteCallParticipant).audioEnabled;
    final videoEnabled = participant is SpreedLocalCallParticipant
        ? localVideoEnabled
        : (participant as SpreedRemoteCallParticipant).videoEnabled;
    return LayoutBuilder(
      builder: (final context, final constraints) => Container(
        margin: const EdgeInsets.all(5),
        child: ClipRRect(
          borderRadius: BorderRadius.circular(10),
          child: ColoredBox(
            color: Theme.of(context).colorScheme.primary,
            child: Stack(
              children: [
                Center(
                  child: hasEnabledVideoTracks && videoEnabled
                      ? RTCVideoView(
                          participant.renderer!,
                          objectFit: RTCVideoViewObjectFit.RTCVideoViewObjectFitCover,
                        )
                      : NeonUserAvatar(
                          account: NeonProvider.of<AccountsBloc>(context).activeAccount.value!,
                          username: participant.userID,
                          showStatus: false,
                          size: min(constraints.maxHeight, constraints.maxWidth) / 2,
                        ),
                ),
                if (!audioEnabled) ...[
                  Align(
                    alignment: Alignment.bottomRight,
                    child: Container(
                      margin: const EdgeInsets.all(5),
                      child: Icon(
                        MdiIcons.microphoneOff,
                        size: 28,
                        color: Theme.of(context).colorScheme.onPrimary,
                      ),
                    ),
                  ),
                ],
              ],
            ),
          ),
        ),
      ),
    );
  }
}
